"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fix = fix;
const read_project_manifest_1 = require("@pnpm/read-project-manifest");
const difference_1 = __importDefault(require("ramda/src/difference"));
async function fix(dir, auditReport) {
    const { manifest, writeProjectManifest } = await (0, read_project_manifest_1.readProjectManifest)(dir);
    const vulnOverrides = createOverrides(Object.values(auditReport.advisories), manifest.pnpm?.auditConfig?.ignoreCves);
    if (Object.values(vulnOverrides).length === 0)
        return vulnOverrides;
    await writeProjectManifest({
        ...manifest,
        pnpm: {
            ...manifest.pnpm,
            overrides: {
                ...manifest.pnpm?.overrides,
                ...vulnOverrides,
            },
        },
    });
    return vulnOverrides;
}
function createOverrides(advisories, ignoreCves) {
    if (ignoreCves) {
        advisories = advisories.filter(({ cves }) => (0, difference_1.default)(cves, ignoreCves).length > 0);
    }
    return Object.fromEntries(advisories
        .filter(({ vulnerable_versions, patched_versions }) => vulnerable_versions !== '>=0.0.0' && patched_versions !== '<0.0.0') // eslint-disable-line
        .map((advisory) => [
        `${advisory.module_name}@${advisory.vulnerable_versions}`,
        advisory.patched_versions,
    ]));
}
//# sourceMappingURL=fix.js.map